@@ -8,10 +8,10 @@ custodian = factory.create_for("cactus-dev", "YOUR-REFRESH-TOKEN-CACTUS-DEV")
 
 # Build tx details
 tx_params = {
-    "from": "0xFA42B2eCf59abD6d6BD4BF07021D870E2FC0eF20",
+    "from_": "0xFA42B2eCf59abD6d6BD4BF07021D870E2FC0eF20",
     "to": "0x7dc55e5C19c43FF6f027d0CeF656B2E1513916e6",
-    "gasLimit": "133997",
-    "value": "0.1",
+    "value": "100000000000000000",  # in Wei
+    "gas": "133997",
     "gasPrice": "200000000000",
 }
 cactus_extra_params = {
